from typing import Final


# ====== CA: Common Attribute ======

class CA:
    Account: Final[str] = "aco"
    Actor: Final[str] = "atr"
    ActorUuid: Final[str] = "atruuid"
    Add: Final[str] = "add"
    Adventurer: Final[str] = "a"
    AdventurerUuid: Final[str] = "auuid"
    All: Final[str] = "all"
    Angle  : Final[str] = "agl"
    Api: Final[str] = "api"
    AppBar: Final[str] = "ab"
    Archive  : Final[str] = "ahe"
    ArchiveTime  : Final[str] = "ahetm"
    ArchiveUuid : Final[str] = "aheuuid"
    Ascending: Final[str] = "asc"  # in SQL
    Auth: Final[str] = "aut"

    Background : Final[str] = "bkg"
    Bean : Final[str] = "ben"
    Blue : Final[str] = "ble"
    Board : Final[str] = "bd"
    BoardDesign : Final[str] = "bddn"
    BoardDesignId : Final[str] = "bddnid"
    BoardId : Final[str] = "bdid"
    Book: Final[str] = "b"
    BookChapterVersionComboId: Final[str] = "bcvcid"
    BookHeadVersionId: Final[str] = "bhvid"
    BookId: Final[str] = "bid"
    BookList: Final[str] = "bl"
    BookListId: Final[str] = "blid"
    BookVersion: Final[str] = "bv"
    BookVersionId: Final[str] = "bvid"
    BookVersionNo: Final[str] = "bvno"
    Bookkeeping: Final[str] = "bk"
    BookkeepingId: Final[str] = "bkid"
    Booster  : Final[str] = "bsr"
    Button: Final[str] = "btn"

    Cancel: Final[str] = "ccl"
    CardSnapshotId : Final[str] = "crdsntid"
    CardSnapshotUuid : Final[str] = "crdsntuuid"
    Catalyst: Final[str] = "ctlt"
    Challenge  : Final[str] = "che"
    ChallengeMs  : Final[str] = "chems"
    ChallengeSec: Final[str] = "chescd"
    Chance  : Final[str] = "cae"
    Chapter: Final[str] = "c"
    ChapterBoneId: Final[str] = "cbnid"
    ChapterBoneWordId: Final[str] = "cbnwid"
    ChapterHeadVersionId: Final[str] = "chvid"
    ChapterId: Final[str] = "cid"
    ChapterVersion: Final[str] = "cv"
    ChapterVersionId: Final[str] = "cvid"
    ChapterVersionNo: Final[str] = "cvno"
    ChapterWordId: Final[str] = "cwid"
    Character: Final[str] = "chr"
    Check: Final[str] = "chk"
    Clear: Final[str] = "cls"
    Click: Final[str] = "clk"
    Close: Final[str] = "cle"
    Code: Final[str] = "cd"
    Collect: Final[str] = "clt"
    Collected: Final[str] = "cltd"
    Color: Final[str] = "col"
    Column : Final[str] = "cln"
    Compass  : Final[str] = "cps"
    Confirm: Final[str] = "cfm"
    Conquered : Final[str] = "cq"
    ConqueredTime: Final[str] = "cqt"
    Context: Final[str] = "ctt"
    Count: Final[str] = "cnt"
    Cover : Final[str] = "cvr"
    CoverCount : Final[str] = "corcnt"
    CoverLayer : Final[str] = "corlyr"
    CoverLayerCount : Final[str] = "corlyrcnt"
    Create: Final[str] = "ct"
    CreateTime: Final[str] = "crt"
    Cube  : Final[str] = "cbe"
    CubeBooster: Final[str] = "cbebsr"
    Current: Final[str] = "curt"

    Data: Final[str] = "dt"
    Database: Final[str] = "db"
    Decorator : Final[str] = "dec"
    Delete: Final[str] = "del"  # in SQL
    Descending: Final[str] = "desc"  # in SQL
    Description: Final[str] = "des"
    DescriptionFormatted: Final[str] = "desf"
    DescriptionId: Final[str] = "desid"
    DescriptionPlain: Final[str] = "desp"
    DesignerId  : Final[str] = "drid"
    DesignerUuid  : Final[str] = "druuid"
    Destination : Final[str] = "dtn"
    Details: Final[str] = "dts"
    Dialog: Final[str] = "dlg"
    Drawer: Final[str] = "dwr"

    Egg: Final[str] = "egg"
    EggCount: Final[str] = "eggcnt"
    ElementR: Final[str] = "elmr"
    ElementG: Final[str] = "elmg"
    ElementB: Final[str] = "elmb"
    ElementY: Final[str] = "elmy"
    ElementV: Final[str] = "elmv"
    Empty: Final[str] = "ety"
    End: Final[str] = "ed"
    Energy: Final[str] = "eny"
    Enter: Final[str] = "ent"
    EnterTime: Final[str] = "enttm"
    Event: Final[str] = "evt"
    EventType: Final[str] = "evttp"
    EventUuid: Final[str] = "evtuuid"

    Failed: Final[str] = "fail"
    Field: Final[str] = "fid"
    Fight : Final[str] = "fgt"
    FightUuid : Final[str] = "fgtuuid"
    Find: Final[str] = "fnd"
    Finished: Final[str] = "fied"
    FinishedWord: Final[str] = "fw"
    First: Final[str] = "fst"
    Focus: Final[str] = "fcs"
    Focused: Final[str] = "fcsd"
    Focusing: Final[str] = "fcsg"
    Footer: Final[str] = "ftr"
    Foreground  : Final[str] = "frg"
    Formatted: Final[str] = "fmt"
    FromUuid: Final[str] = "frmuuid"
    FrontEnd: Final[str] = "fe"

    Goal: Final[str] = "gol"
    GoalCount: Final[str] = "golcnt"
    Gold: Final[str] = "g"
    Green : Final[str] = "grn"
    Grid: Final[str] = "gd"
    Group: Final[str] = "gp"

    Hash: Final[str] = "hash"
    Head: Final[str] = "hd"
    HeadVersion: Final[str] = "hv"
    Header: Final[str] = "hdr"
    Height: Final[str] = "ht"
    HiddenLayer: Final[str] = "hdnlyr"
    HiddenLayerCount: Final[str] = "hdnlyrcnt"
    Hide: Final[str] = "hde"
    History: Final[str] = "hy"
    Home: Final[str] = "he"
    HorizontalFlip : Final[str] = "hrzfp"
    HttpStatus: Final[str] = "hts"

    Id: Final[str] = "id"
    Image : Final[str] = "img"
    Importance: Final[str] = "ipt"
    Info: Final[str] = "inf"
    InfoRow: Final[str] = "inr"
    InfoSnapshotId : Final[str] = "infsntid"
    InfoSnapshotUuid : Final[str] = "infsntuuid"
    Init: Final[str] = "it"
    Input: Final[str] = "inp"
    Item: Final[str] = "im"
    ItemPerPage: Final[str] = "impp"


    Key: Final[str] = "key"

    Lane: Final[str] = "e"
    LaneUuid: Final[str] = "euuid"
    LaneChallengeUuid: Final[str] = "echeuuid"
    LaneDesignUuid: Final[str] = "ednuuid"
    LaneVersionUuid: Final[str] = "evuuid"
    Layer: Final[str] = "lyr"
    Learn: Final[str] = "l"
    LearnBookVersionId: Final[str] = "lbvid"
    # LearnChapterVersionId: Final[str] = 'lcvid'
    Learner: Final[str] = "lr"
    LearnerId: Final[str] = "lrid"
    LearnerSaId: Final[str] = "lrsaid"
    Leave: Final[str] = "le"
    LeaveTime: Final[str] = "letm"
    LeaveType: Final[str] = "letp"
    Length: Final[str] = "lgh"
    Limit: Final[str] = "lmt"
    LimitMove: Final[str] = "lmtmv"
    List: Final[str] = "lt"
    ListWordId: Final[str] = "ltwid"
    Log: Final[str] = "log"
    LogId: Final[str] = "logid"
    Login: Final[str] = "lgn"
    Logo: Final[str] = "loo"
    Logout: Final[str] = "lgo"
    LogUuid: Final[str] = "loguuid"

    Main: Final[str] = "man"
    MainLayer: Final[str] = "manlyr"
    MainLayerCount: Final[str] = "manlyrcnt"
    Major: Final[str] = "mar"
    Manual: Final[str] = "mal"
    ManualBooster: Final[str] = "malbsr"
    Map: Final[str] = "map"
    Mentor: Final[str] = "mr"
    MentorId: Final[str] = "mrid"
    Menu: Final[str] = "mu"
    Message: Final[str] = "msg"
    Minor : Final[str] = "mir"

    Name: Final[str] = "na"
    Navigator: Final[str] = "nav"
    New: Final[str] = "new"
    Next: Final[str] = "nxt"
    NextBookVersion: Final[str] = "nbkv"
    NextPage: Final[str] = "nxp"
    Not: Final[str] = "not"
    Note: Final[str] = "nt"
    NullSquare: Final[str] = "nulsqe"
    NullSquareCount: Final[str] = "nulsqecnt"

    Ok: Final[str] = "ok"
    One: Final[str] = 'one'
    Opacity  : Final[str] = "opy"
    Open: Final[str] = 'opn'
    OrderRank: Final[str] = "odr"

    Page: Final[str] = "pg"
    Parameter: Final[str] = "pm"
    Passed: Final[str] = "pass"
    Password: Final[str] = "pw"
    Percentage : Final[str] = "ptg"
    Permission : Final[str] = "pmn"
    Piece: Final[str] = "pce"
    PieceCount: Final[str] = "pcecnt"
    PieceLayer: Final[str] = "pcelyr"
    Plain: Final[str] = "pn"
    Play : Final[str] = "py"
    PlayVoiceMs : Final[str] = "pyvems"
    Position: Final[str] = "psn"
    Preference: Final[str] = "pfe"
    Previous: Final[str] = 'prs'
    Private: Final[str] = "pvt"
    Privilege: Final[str] = "pvl"
    PreviousPage: Final[str] = "prp"
    Proficiency: Final[str] = 'pfy'
    Public: Final[str] = "pb"
    Publish : Final[str] = "pbh"
    PublishTime: Final[str] = "pbhtm"
    Puzzle: Final[str] = "p"
    PuzzleChallengeUuid: Final[str] = "pcheuuid"
    PuzzleContext: Final[str] = "pctt"
    PuzzleContextUuid: Final[str] = "pcttuuid"
    PuzzleId: Final[str] = "pid"
    PuzzleUuid: Final[str] = "puuid"
    PuzzleDesignId : Final[str] = "pdnid"
    PuzzleDesignHash : Final[str] = "pdnhash"

    Query: Final[str] = "qy"
    Quest: Final[str] = "qt"
    QuestBooster: Final[str] = "qtbsr"
    QuestWfCycleId: Final[str] = "qwcid"
    QuestWfCycleElmId: Final[str] = "qwcelmId"
    Quit: Final[str] = "qut"

    Rate : Final[str] = "rte"
    Read: Final[str] = "rd"
    Red : Final[str] = "red"
    Remove: Final[str] = "rm"
    Request: Final[str] = "req"
    Resource : Final[str] = "res"
    ResourceElement: Final[str] = "reselm"
    Response: Final[str] = "rsp"
    Result: Final[str] = "ret"
    Rhumb  : Final[str] = "rhb"
    Right: Final[str] = "r"
    Role: Final[str] = "rol"
    Rotation: Final[str] = "rot"
    Row : Final[str] = "row"

    SaQuestCount: Final[str] = "saqtcnt"
    SaQuestUuid: Final[str] = "saqtuuid"
    Save: Final[str] = "sav"
    Scale: Final[str] = "scl"
    Search: Final[str] = "sch"
    SearchType: Final[str] = "sht"
    Second: Final[str] = "scd"
    Section: Final[str] = "set"
    Sentence: Final[str] = "sn"
    SentenceAudio: Final[str] = "sa"
    SentenceAudioId: Final[str] = "said"
    SentenceId: Final[str] = "snid"
    Sequence: Final[str] = "seq"
    Series: Final[str] = "ses"
    Shape: Final[str] = "se"
    Show: Final[str] = "shw"
    Signup: Final[str] = "sgu"
    Similarity: Final[str] = "smy"
    Site: Final[str] = "s"
    SiteChallengeUuid: Final[str] = "scheuuid"
    SiteContextUuid: Final[str] = "scttuuid"
    SiteUuid: Final[str] = "suuid"
    Size: Final[str] = "siz"
    Slot: Final[str] = "slt"
    Snapshot: Final[str] = "snt"
    SnapshotId: Final[str] = "sntid"
    SnapshotUuid: Final[str] = "sntuuid"
    SortBy: Final[str] = "stby"
    SortDirection: Final[str] = "stdr"
    SoulSpark: Final[str] = "solspk"
    Space   : Final[str] = "spa"
    Sphere  : Final[str] = "spr"
    Square: Final[str] = "sqe"
    SquareCount: Final[str] = "sqecnt"
    Stand   : Final[str] = "std"
    Star: Final[str] = "str"
    Stars: Final[str] = "strs"
    Start: Final[str] = "str"
    State: Final[str] = "ste"
    Statistics: Final[str] = "stc"
    Status: Final[str] = "sts"
    Summary: Final[str] = "sy"
    Supply: Final[str] = "spl"
    SupplyCount: Final[str] = "splcnt"
    Surface : Final[str] = "sf"

    Tag: Final[str] = "tag"
    Text: Final[str] = "txt"
    Time: Final[str] = "tm"
    TimeNow: Final[str] = "tnw"
    TimeZone: Final[str] = "tmz"
    Title: Final[str] = "tt"
    TitleId: Final[str] = "ttid"
    To: Final[str] = "to"
    Token: Final[str] = "tk"
    TotalCount: Final[str] = "tcnt"
    TotalCountWithoutFilter: Final[str] = "tcntwtf"
    TotalMs: Final[str] = "tlms"
    TotalSec: Final[str] = "tls"
    ToUuid: Final[str] = "touuid"
    Track : Final[str] = "trk"
    TrackSpace : Final[str] = "trkspa"
    Transform: Final[str] = "tsf"
    Type: Final[str] = "tp"

    Unknown: Final[str] = "ukn"
    Update: Final[str] = "ud"
    UpdateTime: Final[str] = "udt"
    Used: Final[str] = "used"
    UsedMs: Final[str] = "usedms"
    User: Final[str] = "usr"
    UserId: Final[str] = "uid"
    UserUuid : Final[str] = "uuuid"
    Util: Final[str] = "util"
    Uuid : Final[str] = "uuid"

    Value: Final[str] = "val"
    Version: Final[str] = "vn"
    VersionCreate: Final[str] = "vct"
    VersionId: Final[str] = "vid"
    VersionNo: Final[str] = "vno"
    VerticalFlip : Final[str] = "vtcfp"
    Visited: Final[str] = "vst"
    Visiting: Final[str] = "vstng"
    Voice: Final[str] = "voc"
    VolWorld: Final[str] = "vw"

    Warning: Final[str] = "wag"
    # WfMedian: Final[str] = "wfm"
    Width: Final[str] = "wh"
    Word: Final[str] = "w"
    WordBookLibrary: Final[str] = "wbl"
    WordFrequency: Final[str] = "wf"
    WordId: Final[str] = "wid"
    WordIdList: Final[str] = "widlst"
    WordIndexList: Final[str] = "windlst"
    WordLearn: Final[str] = 'wl'
    WordLearningState: Final[str] = "wls"
    WordSimilarity: Final[str] = "wsmy"
    WordTags: Final[str] = "wtgs"

    X: Final[str] = "x"

    Y: Final[str] = "y"

    ___Error___: Final[str] = "err"
